# Generated by Django 3.2.2 on 2021-05-06 03:30

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('drf_auth_service', '0003_auto_20201120_1531'),
    ]

    operations = [
        migrations.AddField(
            model_name='ssouser',
            name='created_at',
            field=models.DateTimeField(default=datetime.datetime(2021, 5, 6, 3, 30, 52, 581343)),
        ),
        migrations.AlterField(
            model_name='userlogs',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='logs', to=settings.AUTH_USER_MODEL),
        ),
    ]
