# Generated by Django 3.2.2 on 2021-05-06 03:40

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('drf_auth_service', '0004_auto_20210506_0330'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ssouser',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
